CREATE OR REPLACE PROCEDURE GRAVA_IMPFOS_PRODUTO(
   P_CDFILIAL      IN  FILIAL.CDFILIAL%TYPE,
   P_CDCAIXA       IN  CAIXA.CDCAIXA%TYPE,
   P_DTENTRVENDA   IN  NOTAFISCAL.DTENTRSAID%TYPE,
   P_CDOPERACAO    IN  NOTAFISCAL.CDTIPOOPER%TYPE,
   P_IDORIGEMREDZ  IN  VARCHAR2)
IS
   V_SEQUIMPOSTNF    VARCHAR2(02);
   V_CDIMPICMS       VARCHAR2(02);
   V_CDIMPCARGA      VARCHAR2(02);
   V_IDUTCARGATRIB   VARCHAR2(01);
   V_IDCONSVRBCREDZ  VARCHAR2(01);
   V_CDINSCESTA      VARCHAR2(20);
   V_CDEMPRESA       VARCHAR2(02);
   V_CDCLIENTE       CLIENTE.CDCLIENTE%TYPE;
   V_PAISORIG        VARCHAR2(04);
   V_ESTAORIG        VARCHAR2(02);
   V_IDENDEMIS       VARCHAR2(01);
   V_PAISDEST        VARCHAR2(04);
   V_ESTADEST        VARCHAR2(02);
   V_BASECALC        NUMBER;
   V_INCIDENCIA      VARCHAR2(01);
   V_IDTPIMPOSFIS    VARCHAR2(01);
   V_VRBASECALCRED   NUMBER;
   V_PRIDIGCSTIE     VARCHAR2(01);
BEGIN
   V_SEQUIMPOSTNF := '01';

   /*BUSCA OS CDIGOS DE IMPOSTO, RELACIONADOS AO CDIGO NF-E DOS IMPOSTOS ICMS E CARGA TRIBUTRIA*/
   BEGIN
      SELECT MIN(DECODE(CDIMPOSTONFE,'00',CDIMPOSTO,'')) AS CDICMS,
             MAX(DECODE(CDIMPOSTONFE,'03',CDIMPOSTO,'')) AS CDCARGA
        INTO V_CDIMPICMS, V_CDIMPCARGA
        FROM IMPOSTO
       WHERE CDIMPOSTONFE IN ('00','03');
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_CDIMPICMS  := NULL;
         V_CDIMPCARGA := NULL;
   END;

   /*VERIFICA SE A INSCRIO ESTADUAL EST PARAMETRIZADA PARA UTILIZAR CARGA TRIBUTRIA*/
   V_IDUTCARGATRIB := 'N';
   BEGIN
      SELECT IE.IDUTCARGATRIB, IE.IDCONSVRBCREDZ, FI.CDINSCESTA, FI.CDEMPRESA,IE.CDPAIS, IE.SGESTADO, CDCSTDIG1SAI
        INTO V_IDUTCARGATRIB, V_IDCONSVRBCREDZ, V_CDINSCESTA, V_CDEMPRESA, V_PAISORIG, V_ESTAORIG, V_PRIDIGCSTIE
        FROM FILIAL FI, INSCRESTAD IE
       WHERE FI.CDFILIAL   = P_CDFILIAL
         AND FI.CDINSCESTA = IE.CDINSCESTA
         AND FI.CDEMPRESA  = IE.CDEMPRESA;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_IDUTCARGATRIB  := 'N';
         V_IDCONSVRBCREDZ := 'A';
         V_CDINSCESTA     := '';
         V_CDEMPRESA      := '';
         V_PAISORIG       := '0055';
         V_ESTAORIG       := '';
         V_PRIDIGCSTIE    := '';
   END;

   /*BUSCA AS INFORMAES DE CLIENTE PARA  REALIZAR A CONSULTA DE CFOP E CST NA REDUO Z*/
   BEGIN
      SELECT MAX(P.CDCLIENTE)
        INTO V_CDCLIENTE
        FROM PARAVEND P
       WHERE P.CDFILIAL  = P_CDFILIAL;
   EXCEPTION
        WHEN NO_DATA_FOUND THEN
          V_CDCLIENTE := '';
   END;

   BEGIN
      SELECT NVL(MAX(IDENDCFOPCLI),'P')
        INTO V_IDENDEMIS
        FROM CLIENTE
       WHERE CDCLIENTE = V_CDCLIENTE;
   EXCEPTION
        WHEN NO_DATA_FOUND THEN
          V_IDENDEMIS := 'P';
   END;

   BEGIN
      SELECT MAX(CDPAIS), MAX(SGESTADO)
        INTO V_PAISDEST, V_ESTADEST
        FROM ENDECLIE
       WHERE CDCLIENTE    = V_CDCLIENTE
         AND IDTPENDECLIE = V_IDENDEMIS;
   EXCEPTION
        WHEN NO_DATA_FOUND THEN
          V_PAISDEST := '0055';
          V_ESTADEST := '';
   END;

   /*GERA OS ITENS DA NOTA QUANDO FOR FECHAMENTO DE CUPOM DE REDUO Z*/
   IF ((INSTR('SAT_NFCE',P_IDORIGEMREDZ) = 0) OR (P_IDORIGEMREDZ IS NULL)) THEN
      FOR C_ITEMFISCREDZ IN (SELECT V.CDEMPRESA, V.CDFILIAL, V.IDTPIMPOSFIS, V.CDIMPOSTO, V.VRPEALPRODIT, V.CDPRODUTO,
                                    CST_ITEM (CASE WHEN V.IDTPIMPOSFIS IN ('N','I') THEN V_CDIMPICMS ELSE V.CDIMPOSTO END,V.CDEMPRESA,V_CDINSCESTA,V.CDFILIAL,'0000000000',V_CDCLIENTE,P_CDOPERACAO,P_DTENTRVENDA,V.CDARVPROD,V_PAISORIG,V_ESTAORIG,V_PAISDEST,V_ESTADEST,0) AS CDCSTPROD,
                                    CFOP_ITEM(CASE WHEN V.IDTPIMPOSFIS IN ('N','I') THEN V_CDIMPICMS ELSE V.CDIMPOSTO END,V.CDEMPRESA,V_CDINSCESTA,V.CDFILIAL,V_CDCLIENTE,P_CDOPERACAO,P_DTENTRVENDA,V.CDARVPROD,V_PAISORIG,V_ESTAORIG,V_PAISDEST,V_ESTADEST) AS CFOPITEM,
                                    SUM(V.BASECALC) AS BASECALC, SUM(V.VRIMPOSTO) AS VRIMPOSTO, V.VRPERCREDUCAO, NRLANCTONFFIS, CDFILIALNFFIS
                               FROM (SELECT VD.CDEMPRESA, VD.CDFILIAL, NVL(IP.IDTPIMPOSFIS,'F') AS IDTPIMPOSFIS, IP.CDIMPOSTO, P.CDPRODUTO, P.CDARVPROD, NVL(IP.VRPEALPRODIT,0) AS VRPEALPRODIT,
                                            SUM( TRUNC((IT.QTPRODVEND * (IT.VRUNITVEND+NVL(IT.VRUNITVENDCL,0))),2)-NVL(IT.VRDESITVEND,0)+NVL(IT.VRACRITVEND,0)) AS BASECALC,
                                            SUM((TRUNC((IT.QTPRODVEND * (IT.VRUNITVEND+NVL(IT.VRUNITVENDCL,0))),2)-NVL(IT.VRDESITVEND,0)+NVL(IT.VRACRITVEND,0)) * (IP.VRPEALPRODIT/100)) AS VRIMPOSTO,
                                            A.VRPERCREDUCAO, NRLANCTONFFIS, CDFILIALNFFIS
                                       FROM VENDA VD, ITEMVENDA IT, PRODUTO P, ALIQIMPFIS A,
                                            (SELECT DISTINCT CDFILIAL, CDCAIXA, NRSEQVENDA, NRLANCTONFFIS, CDFILIALNFFIS
                                               FROM MOVCAIXA)MV,
                                            (SELECT IV.CDFILIAL, IV.CDCAIXA, IV.NRSEQVENDA, IV.NRSEQUITVEND,
                                                    I.IDTPIMPOSFIS, IV.VRPEALPRODIT, I.CDIMPOSTO, I.CDIMPOSTONFE
                                               FROM ITVENDAIMPOS IV, IMPOSTO I
                                              WHERE IV.CDIMPOSTO    = I.CDIMPOSTO
                                                AND I.IDTPIMPOSFIS <> 'S' ) IP
                                      WHERE VD.CDEMPRESA    = V_CDEMPRESA
                                        AND VD.CDFILIAL     = P_CDFILIAL
                                        AND VD.CDCAIXA      = P_CDCAIXA
                                        AND VD.IDSITUVENDA  = 'O'
                                        AND VD.DTENTRVENDA  = P_DTENTRVENDA
                                        AND VD.CDFILIAL     = IT.CDFILIAL
                                        AND VD.CDCAIXA      = IT.CDCAIXA
                                        AND VD.NRSEQVENDA   = IT.NRSEQVENDA
                                        AND VD.CDFILIAL     = MV.CDFILIAL
                                        AND VD.CDCAIXA      = MV.CDCAIXA
                                        AND VD.NRSEQVENDA   = MV.NRSEQVENDA
                                        AND VD.CDFILIAL     = IP.CDFILIAL
                                        AND VD.CDCAIXA      = IP.CDCAIXA
                                        AND VD.NRSEQVENDA   = IP.NRSEQVENDA
                                        AND IT.CDFILIAL     = MV.CDFILIAL
                                        AND IT.CDCAIXA      = MV.CDCAIXA
                                        AND IT.NRSEQVENDA   = MV.NRSEQVENDA
                                        AND IT.CDPRODUTO    = P.CDPRODUTO
                                        AND IT.CDFILIAL     = IP.CDFILIAL
                                        AND IT.CDCAIXA      = IP.CDCAIXA
                                        AND IT.NRSEQVENDA   = IP.NRSEQVENDA
                                        AND IT.NRSEQUITVEND = IP.NRSEQUITVEND
                                        AND MV.CDFILIAL     = IP.CDFILIAL
                                        AND MV.CDCAIXA      = IP.CDCAIXA
                                        AND MV.NRSEQVENDA   = IP.NRSEQVENDA
                                        AND A.CDFILIAL      = VD.CDFILIAL
                                        AND A.CDFILIAL      = IT.CDFILIAL
                                        AND A.CDPRODUTO     = IT.CDPRODUTO
                                        AND VD.IDAPROVACAONFCE = 'P'
                                        AND (VD.IDTPEMISVEND NOT IN ('N','S') OR VD.IDTPEMISVEND IS NULL)
                                        AND IP.CDIMPOSTONFE  NOT IN ('50','60')
                                   GROUP BY VD.CDEMPRESA, VD.CDFILIAL, NVL(IP.IDTPIMPOSFIS,'F'), IP.CDIMPOSTO, P.CDPRODUTO, P.CDARVPROD, NVL(IP.VRPEALPRODIT,0), A.VRPERCREDUCAO, NRLANCTONFFIS, CDFILIALNFFIS)V
                               GROUP BY V.CDEMPRESA, V.CDFILIAL, V.IDTPIMPOSFIS, V.CDIMPOSTO, V.VRPEALPRODIT, V.CDPRODUTO, V.VRPERCREDUCAO, NRLANCTONFFIS, CDFILIALNFFIS,
                                        CST_ITEM (CASE WHEN V.IDTPIMPOSFIS IN ('N','I') THEN V_CDIMPICMS ELSE V.CDIMPOSTO END,V.CDEMPRESA,V_CDINSCESTA,V.CDFILIAL,'0000000000',V_CDCLIENTE,P_CDOPERACAO,P_DTENTRVENDA,V.CDARVPROD,V_PAISORIG,V_ESTAORIG,V_PAISDEST,V_ESTADEST,0),
                                        CFOP_ITEM(CASE WHEN V.IDTPIMPOSFIS IN ('N','I') THEN V_CDIMPICMS ELSE V.CDIMPOSTO END,V.CDEMPRESA,V_CDINSCESTA,V.CDFILIAL,V_CDCLIENTE,P_CDOPERACAO,P_DTENTRVENDA,V.CDARVPROD,V_PAISORIG,V_ESTAORIG,V_PAISDEST,V_ESTADEST))LOOP

         /*VERIFICA A INCIDNCIA DO ICMS OU ICMS ST*/
         IF (C_ITEMFISCREDZ.IDTPIMPOSFIS = 'T') THEN
            V_INCIDENCIA    := '1';
            V_BASECALC      := C_ITEMFISCREDZ.BASECALC;
            V_IDTPIMPOSFIS  := 'T';
         ELSIF (C_ITEMFISCREDZ.IDTPIMPOSFIS = 'F') THEN
            V_INCIDENCIA   := '3';
            V_BASECALC     := 0;
            V_IDTPIMPOSFIS := 'F';
         ELSIF ((C_ITEMFISCREDZ.IDTPIMPOSFIS = 'N') OR (C_ITEMFISCREDZ.IDTPIMPOSFIS IS NULL)) THEN
            V_INCIDENCIA   := '3';
            V_BASECALC     := 0;
            V_IDTPIMPOSFIS := 'N';
         ELSE
            V_INCIDENCIA   := '2';
            V_BASECALC     := 0;
            V_IDTPIMPOSFIS := 'I';
         END IF;

         /*VERIFICA SE A INSCRIO ESTADUAL UTILIZA CARGA TRIBUTRIA, E SE O IMPOSTO  O ICMS*/
         IF (V_IDUTCARGATRIB = 'S') AND (V_IDTPIMPOSFIS = 'T') AND (V_CDIMPCARGA IS NOT NULL) THEN
            /*EM CASO AFIRMATIVO, INSERE A LINHA TRIBUTADA PARA IMPOSTO DE CARGA*/
            INSERT INTO IMPPRODVENDAFIS
               (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE, CDIMPOSTO, CDPRODUTO,
                NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT, CDTIPOOPER,
                VRCONTABIL, VRBASECALC, VRALIQIT,
                VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                CDFILIALNFFIS, NRLANCTONFFIS)
            VALUES
               (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, P_DTENTRVENDA, V_CDIMPCARGA, C_ITEMFISCREDZ.CDPRODUTO,
                V_SEQUIMPOSTNF, C_ITEMFISCREDZ.CDCSTPROD, SUBSTR(C_ITEMFISCREDZ.CFOPITEM,3,14), P_CDOPERACAO,
                TRUNC(NVL(C_ITEMFISCREDZ.BASECALC,0),2), TRUNC(V_BASECALC,2), NVL(C_ITEMFISCREDZ.VRPEALPRODIT,0),
                NVL(C_ITEMFISCREDZ.VRIMPOSTO,0), V_INCIDENCIA, '1', P_IDORIGEMREDZ,
                C_ITEMFISCREDZ.CDFILIALNFFIS, C_ITEMFISCREDZ.NRLANCTONFFIS);

            V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);

            /*E UMA LINHA COM CDIGO FISCAL 3 PARA O ICMS NORMAL*/
            INSERT INTO IMPPRODVENDAFIS
               (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE, CDIMPOSTO, CDPRODUTO,
                NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT, CDTIPOOPER,
                VRCONTABIL, VRBASECALC, VRALIQIT, VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                CDFILIALNFFIS, NRLANCTONFFIS)
            VALUES
               (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, P_DTENTRVENDA, C_ITEMFISCREDZ.CDIMPOSTO, C_ITEMFISCREDZ.CDPRODUTO,
                V_SEQUIMPOSTNF, C_ITEMFISCREDZ.CDCSTPROD, SUBSTR(C_ITEMFISCREDZ.CFOPITEM,3,14), P_CDOPERACAO,
                TRUNC(NVL(C_ITEMFISCREDZ.BASECALC,0),2), 0.0, 0.0, 0.0, '3', '1', P_IDORIGEMREDZ,
                C_ITEMFISCREDZ.CDFILIALNFFIS, C_ITEMFISCREDZ.NRLANCTONFFIS);

            V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);
         ELSE
            /*VERIFICA SE A INSCRIO ESTADUAL UTILIZA REDUO DA BASE DE CLCULO APENAS NO MDULO FISCAL,
              SE O IMPOSTO  O ICMS E POSSUI REDUO DA BASE*/
            IF (V_IDCONSVRBCREDZ = 'B') AND (V_IDTPIMPOSFIS = 'T') AND (C_ITEMFISCREDZ.VRPERCREDUCAO > 0) AND (V_BASECALC > 0) THEN
               /*CLCULA O VALOR A SER REDUZIDO DA BASE DE CLCULO*/
               V_VRBASECALCRED := ROUND(V_BASECALC*C_ITEMFISCREDZ.VRPERCREDUCAO/100,2);
               V_BASECALC      := V_BASECALC - V_VRBASECALCRED;
               /*INSERE A LINHA COM A BASE REDUZIDA*/
               INSERT INTO IMPPRODVENDAFIS
                  (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE, CDIMPOSTO, CDPRODUTO,
                   NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT, CDTIPOOPER,
                   VRCONTABIL, VRBASECALC, VRALIQIT,
                   VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                   CDFILIALNFFIS, NRLANCTONFFIS)
               VALUES
                  (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, P_DTENTRVENDA, V_CDIMPICMS, C_ITEMFISCREDZ.CDPRODUTO,
                   V_SEQUIMPOSTNF, C_ITEMFISCREDZ.CDCSTPROD, SUBSTR(C_ITEMFISCREDZ.CFOPITEM,3,14), P_CDOPERACAO,
                   TRUNC(NVL(V_BASECALC,0),2), TRUNC(NVL(V_BASECALC,0),2), NVL(C_ITEMFISCREDZ.VRPEALPRODIT,0),
                   V_BASECALC*C_ITEMFISCREDZ.VRPEALPRODIT/100, '1', '1', P_IDORIGEMREDZ,
                   C_ITEMFISCREDZ.CDFILIALNFFIS, C_ITEMFISCREDZ.NRLANCTONFFIS);

               V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);

               /*INSERE A LINHA COM CDIGO FISCAL 2, COM O COMPLEMENTO DO VALOR CONTBIL*/
               INSERT INTO IMPPRODVENDAFIS
                  (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE, CDIMPOSTO, CDPRODUTO,
                   NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT, CDTIPOOPER,
                   VRCONTABIL, VRBASECALC, VRALIQIT, VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                   CDFILIALNFFIS, NRLANCTONFFIS)
               VALUES
                  (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, P_DTENTRVENDA, V_CDIMPICMS, C_ITEMFISCREDZ.CDPRODUTO,
                   V_SEQUIMPOSTNF, C_ITEMFISCREDZ.CDCSTPROD, SUBSTR(C_ITEMFISCREDZ.CFOPITEM,3,14), P_CDOPERACAO,
                   TRUNC(NVL(V_VRBASECALCRED,0),2), 0.00, 0.00, 0.00, '2', '2', P_IDORIGEMREDZ,
                   C_ITEMFISCREDZ.CDFILIALNFFIS, C_ITEMFISCREDZ.NRLANCTONFFIS);

               V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);
            ELSE
               /*CASO CONTRRIO INSERE A LINHA DO IMPOSTO NORMALMENTE*/
               INSERT INTO IMPPRODVENDAFIS
                  (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE,
                   CDIMPOSTO, CDPRODUTO,
                   NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT, CDTIPOOPER,
                   VRCONTABIL, VRBASECALC, VRALIQIT,
                   VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                   CDFILIALNFFIS, NRLANCTONFFIS)
               VALUES
                  (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, P_DTENTRVENDA,
                   CASE WHEN V_IDTPIMPOSFIS IN ('N','I') THEN V_CDIMPICMS ELSE C_ITEMFISCREDZ.CDIMPOSTO END, C_ITEMFISCREDZ.CDPRODUTO,
                   V_SEQUIMPOSTNF, C_ITEMFISCREDZ.CDCSTPROD, SUBSTR(C_ITEMFISCREDZ.CFOPITEM,3,14), P_CDOPERACAO,
                   TRUNC(NVL(C_ITEMFISCREDZ.BASECALC,0),2), TRUNC(V_BASECALC,2), NVL(C_ITEMFISCREDZ.VRPEALPRODIT,0),
                   NVL(C_ITEMFISCREDZ.VRIMPOSTO,0), V_INCIDENCIA, '1', P_IDORIGEMREDZ,
                   C_ITEMFISCREDZ.CDFILIALNFFIS, C_ITEMFISCREDZ.NRLANCTONFFIS);

               V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);

               /*VERIFICA SE O IMPOSTO  O ICMS ST, POIS NESSE CASO  NECESSRIO INSERIR
                 UMA LINHA CORRESPONDENTE PARA O ICMS, EVITANDO DIFERENAS NO VALOR CONTBIL NOS RELATRIOS*/
               IF V_IDTPIMPOSFIS = 'F' THEN
                  INSERT INTO IMPPRODVENDAFIS
                     (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE, CDIMPOSTO, CDPRODUTO,
                      NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT, CDTIPOOPER,
                      VRCONTABIL, VRBASECALC, VRALIQIT, VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                      CDFILIALNFFIS, NRLANCTONFFIS)
                  VALUES
                     (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, P_DTENTRVENDA, V_CDIMPICMS, C_ITEMFISCREDZ.CDPRODUTO,
                      V_SEQUIMPOSTNF, C_ITEMFISCREDZ.CDCSTPROD, SUBSTR(C_ITEMFISCREDZ.CFOPITEM,3,14), P_CDOPERACAO,
                      TRUNC(NVL(C_ITEMFISCREDZ.BASECALC,0),2), 0.00, 0.00, 0.00, '3', '1', P_IDORIGEMREDZ,
                      C_ITEMFISCREDZ.CDFILIALNFFIS, C_ITEMFISCREDZ.NRLANCTONFFIS);

                  V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);
               END IF;
            END IF;
         END IF;
      END LOOP;
   END IF;

   /*GERA OS ITENS DA NOTA QUANDO FOR FECHAMENTO DE CUPOM DE NFC-E*/
   IF (P_IDORIGEMREDZ = 'NFCE') THEN
      FOR C_ITEMFISCNFCE IN (SELECT VD.CDEMPRESA, VD.CDFILIAL, NVL(IP.IDTPIMPOSFIS,'F') AS IDTPIMPOSFIS, IP.CDIMPOSTO, TRUNC(VD.DTEMISSAONFCE) AS DTEMISSAONFCE,
                                    SUBSTR(LPAD(NVL(P.CDCSTDIG1PROD,V_PRIDIGCSTIE)||IP.CDCSTPRODI,4,'0'),2,3) AS CDCSTPROD, IP.CDCFOPPROD AS CFOPITEM,
                                    NVL(IP.VRPEALPRODIT,0) AS VRPEALPRODIT, SUM(TRUNC(IP.VRIMPOPRODIT,2)) AS VRIMPOSTO, P.CDPRODUTO, NRLANCTONFFIS, CDFILIALNFFIS,
                                    SUM(TRUNC((IT.QTPRODVEND*(IT.VRUNITVEND+NVL(IT.VRUNITVENDCL,0))-NVL(IT.VRDESITVEND,0)+NVL(IT.VRACRITVEND,0)),2)) AS BASECALC
                               FROM VENDA VD, ITEMVENDA IT, PRODUTO P,
                                    (SELECT DISTINCT CDFILIAL, CDCAIXA, NRSEQVENDA, NRLANCTONFFIS, CDFILIALNFFIS
                                       FROM MOVCAIXA)MV,
                                    (SELECT IV.CDFILIAL, IV.CDCAIXA, IV.NRSEQVENDA, IV.NRSEQUITVEND, I.IDTPIMPOSFIS,
                                            IV.VRPERPIS, IV.VRPERCOFINS, IV.VRPEALPRODIT, I.CDIMPOSTO, I.CDIMPOSTONFE,
                                            IV.CDCSTPRODI, IV.CDCSTPRODPC, IV.CDCFOPPROD, IV.VRIMPOPRODIT
                                       FROM ITVENDAIMPOS IV, IMPOSTO I
                                      WHERE IV.CDIMPOSTO = I.CDIMPOSTO
                                        AND I.IDTPIMPOSFIS <> 'S') IP
                              WHERE VD.CDEMPRESA     = V_CDEMPRESA
                                AND VD.CDFILIAL      = P_CDFILIAL
                                AND VD.CDCAIXA       = P_CDCAIXA
                                AND VD.IDSITUVENDA   = 'O'
                                AND VD.IDTPAMBNFCE   = '1'
                                AND VD.IDSTATUSNFCE  = 'A'
                                AND VD.IDTPEMISVEND  = 'N'
                                AND TRUNC(VD.DTENTRVENDA)   = P_DTENTRVENDA
                                AND VD.CDFILIAL      = IT.CDFILIAL
                                AND VD.CDCAIXA       = IT.CDCAIXA
                                AND VD.NRSEQVENDA    = IT.NRSEQVENDA
                                AND VD.CDFILIAL      = MV.CDFILIAL
                                AND VD.CDCAIXA       = MV.CDCAIXA
                                AND VD.NRSEQVENDA    = MV.NRSEQVENDA
                                AND VD.CDFILIAL      = IP.CDFILIAL
                                AND VD.CDCAIXA       = IP.CDCAIXA
                                AND VD.NRSEQVENDA    = IP.NRSEQVENDA
                                AND IT.CDFILIAL      = MV.CDFILIAL
                                AND IT.CDCAIXA       = MV.CDCAIXA
                                AND IT.NRSEQVENDA    = MV.NRSEQVENDA
                                AND IT.CDPRODUTO     = P.CDPRODUTO
                                AND IT.CDFILIAL      = IP.CDFILIAL
                                AND IT.CDCAIXA       = IP.CDCAIXA
                                AND IT.NRSEQVENDA    = IP.NRSEQVENDA
                                AND IT.NRSEQUITVEND  = IP.NRSEQUITVEND
                                AND IP.CDFILIAL      = MV.CDFILIAL
                                AND IP.CDCAIXA       = MV.CDCAIXA
                                AND IP.NRSEQVENDA    = MV.NRSEQVENDA
                                AND VD.IDAPROVACAONFCE = 'P'
                                AND IP.CDIMPOSTONFE  IN ('00','80')
                              GROUP BY VD.CDEMPRESA, VD.CDFILIAL, NVL(IP.IDTPIMPOSFIS,'F'), IP.CDIMPOSTO, TRUNC(VD.DTEMISSAONFCE),
                                    SUBSTR(LPAD(NVL(P.CDCSTDIG1PROD,V_PRIDIGCSTIE)||IP.CDCSTPRODI,4,'0'),2,3), P.CDPRODUTO,
                                    IP.CDCFOPPROD, NVL(IP.VRPEALPRODIT,0), NRLANCTONFFIS, CDFILIALNFFIS
                              ORDER BY IP.CDIMPOSTO) LOOP

         /*VERIFICA A INCIDNCIA DO ICMS OU ICMS ST*/
         IF ((C_ITEMFISCNFCE.IDTPIMPOSFIS = 'T') OR (C_ITEMFISCNFCE.VRIMPOSTO > 0)) THEN
            V_INCIDENCIA    := '1';
            V_BASECALC      := C_ITEMFISCNFCE.BASECALC;
            V_IDTPIMPOSFIS  := 'T';
         ELSIF (C_ITEMFISCNFCE.IDTPIMPOSFIS = 'F') THEN
            V_INCIDENCIA   := '3';
            V_BASECALC     := 0;
            V_IDTPIMPOSFIS := 'F';
         ELSIF ((C_ITEMFISCNFCE.IDTPIMPOSFIS = 'N') OR (C_ITEMFISCNFCE.IDTPIMPOSFIS IS NULL)) THEN
            V_INCIDENCIA   := '3';
            V_BASECALC     := 0;
            V_IDTPIMPOSFIS := 'N';
         ELSE
            V_INCIDENCIA   := '2';
            V_BASECALC     := 0;
            V_IDTPIMPOSFIS := 'I';
         END IF;

         /*VERIFICA SE A INSCRIO ESTADUAL UTILIZA CARGA TRIBUTRIA, E SE O IMPOSTO  O ICMS*/
         IF (V_IDUTCARGATRIB = 'S') AND (V_IDTPIMPOSFIS = 'T') AND (V_CDIMPCARGA IS NOT NULL) THEN
            /*EM CASO AFIRMATIVO, INSERE A LINHA TRIBUTADA PARA IMPOSTO DE CARGA*/
           INSERT INTO IMPPRODVENDAFIS
               (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE, CDIMPOSTO, CDPRODUTO,
                NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT, CDTIPOOPER,
                VRCONTABIL, VRBASECALC, VRALIQIT,
                VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                CDFILIALNFFIS, NRLANCTONFFIS)
            VALUES
               (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, C_ITEMFISCNFCE.DTEMISSAONFCE, V_CDIMPCARGA, C_ITEMFISCNFCE.CDPRODUTO,
                V_SEQUIMPOSTNF, C_ITEMFISCNFCE.CDCSTPROD, C_ITEMFISCNFCE.CFOPITEM, P_CDOPERACAO,
                TRUNC(NVL(C_ITEMFISCNFCE.BASECALC,0),2), TRUNC(V_BASECALC,2), NVL(C_ITEMFISCNFCE.VRPEALPRODIT,0),
                NVL(C_ITEMFISCNFCE.VRIMPOSTO,0), V_INCIDENCIA, '1', P_IDORIGEMREDZ,
                C_ITEMFISCNFCE.CDFILIALNFFIS, C_ITEMFISCNFCE.NRLANCTONFFIS);

            V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);

            /*E UMA LINHA COM CDIGO FISCAL 3 PARA O ICMS NORMAL*/
            INSERT INTO IMPPRODVENDAFIS
               (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE, CDIMPOSTO, CDPRODUTO,
                NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT, CDTIPOOPER,
                VRCONTABIL, VRBASECALC, VRALIQIT, VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                CDFILIALNFFIS, NRLANCTONFFIS)
            VALUES
               (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, C_ITEMFISCNFCE.DTEMISSAONFCE, C_ITEMFISCNFCE.CDIMPOSTO, C_ITEMFISCNFCE.CDPRODUTO,
                V_SEQUIMPOSTNF, C_ITEMFISCNFCE.CDCSTPROD, C_ITEMFISCNFCE.CFOPITEM, P_CDOPERACAO,
                TRUNC(NVL(C_ITEMFISCNFCE.BASECALC,0),2), 0.0, 0.0, 0.0, '3', '1', P_IDORIGEMREDZ,
                C_ITEMFISCNFCE.CDFILIALNFFIS, C_ITEMFISCNFCE.NRLANCTONFFIS);

            V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);
         ELSE
            /*CASO CONTRRIO INSERE A LINHA DO IMPOSTO NORMALMENTE*/
            INSERT INTO IMPPRODVENDAFIS
               (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE,
                CDIMPOSTO, CDPRODUTO,
                NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT, CDTIPOOPER,
                VRCONTABIL, VRBASECALC, VRALIQIT,
                VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                CDFILIALNFFIS, NRLANCTONFFIS)
            VALUES
               (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, C_ITEMFISCNFCE.DTEMISSAONFCE,
                CASE WHEN V_IDTPIMPOSFIS IN ('N','I') THEN V_CDIMPICMS ELSE C_ITEMFISCNFCE.CDIMPOSTO END, C_ITEMFISCNFCE.CDPRODUTO,
                V_SEQUIMPOSTNF, C_ITEMFISCNFCE.CDCSTPROD, C_ITEMFISCNFCE.CFOPITEM, P_CDOPERACAO,
                TRUNC(NVL(C_ITEMFISCNFCE.BASECALC,0),2), TRUNC(V_BASECALC,2), NVL(C_ITEMFISCNFCE.VRPEALPRODIT,0),
                NVL(C_ITEMFISCNFCE.VRIMPOSTO,0), V_INCIDENCIA, '1', P_IDORIGEMREDZ,
                C_ITEMFISCNFCE.CDFILIALNFFIS, C_ITEMFISCNFCE.NRLANCTONFFIS);

            V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);

            /*VERIFICA SE O IMPOSTO  O ICMS ST, POIS NESSE CASO  NECESSRIO INSERIR
              UMA LINHA CORRESPONDENTE PARA O ICMS, EVITANDO DIFERENAS NO VALOR CONTBIL*/
            IF V_IDTPIMPOSFIS = 'F' THEN
               INSERT INTO IMPPRODVENDAFIS
                  (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE, CDIMPOSTO, CDPRODUTO,
                   NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT, CDTIPOOPER,
                   VRCONTABIL, VRBASECALC, VRALIQIT, VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                   CDFILIALNFFIS, NRLANCTONFFIS)
               VALUES
                  (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, C_ITEMFISCNFCE.DTEMISSAONFCE, V_CDIMPICMS, C_ITEMFISCNFCE.CDPRODUTO,
                   V_SEQUIMPOSTNF, C_ITEMFISCNFCE.CDCSTPROD, C_ITEMFISCNFCE.CFOPITEM, P_CDOPERACAO,
                   TRUNC(NVL(C_ITEMFISCNFCE.BASECALC,0),2), 0.00, 0.00, 0.00, '3', '1', P_IDORIGEMREDZ,
                   C_ITEMFISCNFCE.CDFILIALNFFIS, C_ITEMFISCNFCE.NRLANCTONFFIS);

               V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);
            END IF;
         END IF;
      END LOOP;
   END IF;

   /*GERA OS ITENS DA NOTA QUANDO FOR FECHAMENTO DE CUPOM DE SAT*/
   IF P_IDORIGEMREDZ = 'SAT' THEN
      FOR C_ITEMFISCSAT IN (SELECT VD.CDEMPRESA, VD.CDFILIAL, NVL(IP.IDTPIMPOSFIS,'F') AS IDTPIMPOSFIS, IP.CDIMPOSTO, TRUNC(VD.DTEMISSAONFCE) AS DTEMISSAONFCE,
                                   SUBSTR(LPAD(NVL(P.CDCSTDIG1PROD,V_PRIDIGCSTIE)||IP.CDCSTPRODI,4,'0'),2,3) AS CDCSTPROD, IP.CDCFOPPROD AS CFOPITEM,
                                   NVL(IP.VRPEALPRODIT,0) AS VRPEALPRODIT, SUM(ROUND(IP.VRIMPOPRODIT,2)) AS VRIMPOSTO, P.CDPRODUTO, NRLANCTONFFIS, CDFILIALNFFIS,
                                   SUM(TRUNC((IT.QTPRODVEND*(IT.VRUNITVEND+NVL(IT.VRUNITVENDCL,0))-NVL(IT.VRDESITVEND,0)+NVL(IT.VRACRITVEND,0)),2)) AS BASECALC
                              FROM VENDA VD, ITEMVENDA IT, PRODUTO P,
                                   (SELECT DISTINCT CDFILIAL, CDCAIXA, NRSEQVENDA, NRLANCTONFFIS, CDFILIALNFFIS
                                      FROM MOVCAIXA)MV,
                                   (SELECT IV.CDFILIAL, IV.CDCAIXA, IV.NRSEQVENDA, IV.NRSEQUITVEND, I.IDTPIMPOSFIS,
                                           IV.VRPERPIS, IV.VRPERCOFINS, IV.VRPEALPRODIT, I.CDIMPOSTO, I.CDIMPOSTONFE,
                                           IV.CDCSTPRODI, IV.CDCSTPRODPC, IV.CDCFOPPROD, IV.VRIMPOPRODIT
                                      FROM ITVENDAIMPOS IV, IMPOSTO I
                                     WHERE IV.CDIMPOSTO = I.CDIMPOSTO
                                       AND I.IDTPIMPOSFIS <> 'S') IP
                             WHERE VD.CDEMPRESA     = V_CDEMPRESA
                               AND VD.CDFILIAL      = P_CDFILIAL
                               AND VD.CDCAIXA       = P_CDCAIXA
                               AND VD.IDSITUVENDA   = 'O'
                               AND VD.IDTPAMBNFCE   = '1'
                               AND VD.IDSTATUSNFCE  = 'A'
                               AND VD.IDTPEMISVEND  = 'S'
                               AND TRUNC(VD.DTENTRVENDA) = P_DTENTRVENDA
                               AND VD.CDFILIAL      = IT.CDFILIAL
                               AND VD.CDCAIXA       = IT.CDCAIXA
                               AND VD.NRSEQVENDA    = IT.NRSEQVENDA
                               AND VD.CDFILIAL      = MV.CDFILIAL
                               AND VD.CDCAIXA       = MV.CDCAIXA
                               AND VD.NRSEQVENDA    = MV.NRSEQVENDA
                               AND VD.CDFILIAL      = IP.CDFILIAL
                               AND VD.CDCAIXA       = IP.CDCAIXA
                               AND VD.NRSEQVENDA    = IP.NRSEQVENDA
                               AND IT.CDFILIAL      = MV.CDFILIAL
                               AND IT.CDCAIXA       = MV.CDCAIXA
                               AND IT.NRSEQVENDA    = MV.NRSEQVENDA
                               AND IT.CDPRODUTO     = P.CDPRODUTO
                               AND IT.CDFILIAL      = IP.CDFILIAL
                               AND IT.CDCAIXA       = IP.CDCAIXA
                               AND IT.NRSEQVENDA    = IP.NRSEQVENDA
                               AND IT.NRSEQUITVEND  = IP.NRSEQUITVEND
                               AND IP.CDFILIAL      = MV.CDFILIAL
                               AND IP.CDCAIXA       = MV.CDCAIXA
                               AND IP.NRSEQVENDA    = MV.NRSEQVENDA
                               AND VD.IDAPROVACAONFCE = 'P'
                               AND IP.CDIMPOSTONFE  IN ('00','80')
                             GROUP BY VD.CDEMPRESA, VD.CDFILIAL, NVL(IP.IDTPIMPOSFIS,'F'), IP.CDIMPOSTO, TRUNC(VD.DTEMISSAONFCE),
                                   SUBSTR(LPAD(NVL(P.CDCSTDIG1PROD,V_PRIDIGCSTIE)||IP.CDCSTPRODI,4,'0'),2,3), P.CDPRODUTO,
                                   IP.CDCFOPPROD, NVL(IP.VRPEALPRODIT,0), NRLANCTONFFIS, CDFILIALNFFIS
                             ORDER BY IP.CDIMPOSTO) LOOP

         /*VERIFICA A INCIDNCIA DO ICMS OU ICMS ST*/
         IF ((C_ITEMFISCSAT.IDTPIMPOSFIS = 'T') OR (C_ITEMFISCSAT.VRIMPOSTO > 0)) THEN
            V_INCIDENCIA    := '1';
            V_BASECALC      := C_ITEMFISCSAT.BASECALC;
            V_IDTPIMPOSFIS  := 'T';
         ELSIF (C_ITEMFISCSAT.IDTPIMPOSFIS = 'F') THEN
            V_INCIDENCIA   := '3';
            V_BASECALC     := 0;
            V_IDTPIMPOSFIS := 'F';
         ELSIF ((C_ITEMFISCSAT.IDTPIMPOSFIS = 'N') OR (C_ITEMFISCSAT.IDTPIMPOSFIS IS NULL)) THEN
            V_INCIDENCIA   := '3';
            V_BASECALC     := 0;
            V_IDTPIMPOSFIS := 'N';
         ELSE
            V_INCIDENCIA   := '2';
            V_BASECALC     := 0;
            V_IDTPIMPOSFIS := 'I';
         END IF;

         /*VERIFICA SE A INSCRIO ESTADUAL UTILIZA CARGA TRIBUTRIA, E SE O IMPOSTO  O ICMS*/
         IF (V_IDUTCARGATRIB = 'S') AND (V_IDTPIMPOSFIS = 'T') AND (V_CDIMPCARGA IS NOT NULL) THEN
            /*EM CASO AFIRMATIVO, INSERE A LINHA TRIBUTADA PARA IMPOSTO DE CARGA*/
            INSERT INTO IMPPRODVENDAFIS
               (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE, CDIMPOSTO,
                CDPRODUTO, NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT,
                CDTIPOOPER, VRCONTABIL, VRBASECALC,
                VRALIQIT, VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                CDFILIALNFFIS, NRLANCTONFFIS)
            VALUES
               (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, C_ITEMFISCSAT.DTEMISSAONFCE, V_CDIMPCARGA,
                C_ITEMFISCSAT.CDPRODUTO, V_SEQUIMPOSTNF, C_ITEMFISCSAT.CDCSTPROD, C_ITEMFISCSAT.CFOPITEM,
                P_CDOPERACAO, TRUNC(NVL(C_ITEMFISCSAT.BASECALC,0),2), TRUNC(V_BASECALC,2),
                NVL(C_ITEMFISCSAT.VRPEALPRODIT,0), NVL(C_ITEMFISCSAT.VRIMPOSTO,0), V_INCIDENCIA, '1', P_IDORIGEMREDZ,
                C_ITEMFISCSAT.CDFILIALNFFIS, C_ITEMFISCSAT.NRLANCTONFFIS);

            V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);

            /*E UMA LINHA COM CDIGO FISCAL 3 PARA O ICMS NORMAL*/
            INSERT INTO IMPPRODVENDAFIS
               (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE, CDIMPOSTO,
                CDPRODUTO, NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT,
                CDTIPOOPER, VRCONTABIL, VRBASECALC, VRALIQIT, VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                CDFILIALNFFIS, NRLANCTONFFIS)
            VALUES
               (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, C_ITEMFISCSAT.DTEMISSAONFCE, C_ITEMFISCSAT.CDIMPOSTO,
                C_ITEMFISCSAT.CDPRODUTO, V_SEQUIMPOSTNF, C_ITEMFISCSAT.CDCSTPROD, C_ITEMFISCSAT.CFOPITEM,
                P_CDOPERACAO, TRUNC(NVL(C_ITEMFISCSAT.BASECALC,0),2), 0.0, 0.0, 0.0, '3', '1', P_IDORIGEMREDZ,
                C_ITEMFISCSAT.CDFILIALNFFIS, C_ITEMFISCSAT.NRLANCTONFFIS);

            V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);
         ELSE
            /*CASO CONTRRIO INSERE A LINHA DO IMPOSTO NORMALMENTE*/
            INSERT INTO IMPPRODVENDAFIS
               (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE,
                CDIMPOSTO, CDPRODUTO,
                NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT, CDTIPOOPER,
                VRCONTABIL, VRBASECALC, VRALIQIT,
                VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                CDFILIALNFFIS, NRLANCTONFFIS)
            VALUES
               (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, C_ITEMFISCSAT.DTEMISSAONFCE,
                CASE WHEN V_IDTPIMPOSFIS IN ('N','I') THEN V_CDIMPICMS ELSE C_ITEMFISCSAT.CDIMPOSTO END, C_ITEMFISCSAT.CDPRODUTO,
                V_SEQUIMPOSTNF, C_ITEMFISCSAT.CDCSTPROD, C_ITEMFISCSAT.CFOPITEM, P_CDOPERACAO,
                TRUNC(NVL(C_ITEMFISCSAT.BASECALC,0),2), TRUNC(V_BASECALC,2), NVL(C_ITEMFISCSAT.VRPEALPRODIT,0),
                NVL(C_ITEMFISCSAT.VRIMPOSTO,0), V_INCIDENCIA, '1', P_IDORIGEMREDZ,
                C_ITEMFISCSAT.CDFILIALNFFIS, C_ITEMFISCSAT.NRLANCTONFFIS);

            V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);

            /*VERIFICA SE O IMPOSTO  O ICMS ST, POIS NESSE CASO  NECESSRIO INSERIR
              UMA LINHA CORRESPONDENTE PARA O ICMS, EVITANDO DIFERENAS NO VALOR CONTBIL*/
            IF V_IDTPIMPOSFIS = 'F' THEN
               INSERT INTO IMPPRODVENDAFIS
                  (CDFILIAL, CDCAIXA, DTENTRVENDA, DTEMISSAONFCE, CDIMPOSTO,
                   CDPRODUTO, NRIMPOSIT, CDSITUTRIBIT, CDFISCOPERIT,
                   CDTIPOOPER, VRCONTABIL, VRBASECALC, VRALIQIT, VRIMPOSTO, CDFISCALIT, NRITPROIMPOS, IDORIGEMVENDA,
                   CDFILIALNFFIS, NRLANCTONFFIS)
               VALUES
                  (P_CDFILIAL, P_CDCAIXA, P_DTENTRVENDA, C_ITEMFISCSAT.DTEMISSAONFCE, V_CDIMPICMS,
                   C_ITEMFISCSAT.CDPRODUTO, V_SEQUIMPOSTNF, C_ITEMFISCSAT.CDCSTPROD, C_ITEMFISCSAT.CFOPITEM,
                   P_CDOPERACAO, TRUNC(NVL(C_ITEMFISCSAT.BASECALC,0),2), 0.00, 0.00, 0.00, '3', '1', P_IDORIGEMREDZ,
                   C_ITEMFISCSAT.CDFILIALNFFIS, C_ITEMFISCSAT.NRLANCTONFFIS);

               V_SEQUIMPOSTNF := LPAD(RTRIM(TO_CHAR(TO_NUMBER(V_SEQUIMPOSTNF) + 1)),2,0);
            END IF;
         END IF;
      END LOOP;
   END IF;
EXCEPTION
   WHEN OTHERS THEN BEGIN
      RAISE_APPLICATION_ERROR(-20501,SQLERRM(SQLCODE),TRUE);
   END;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('GRAVA_IMPFOS_PRODUTO','6.05.xxx'); END;
/

