CREATE OR REPLACE PROCEDURE APURA_ICMSST_IESUBSTITUTO(
    P_DTFINAL        IN MAPAAPURAC.DTINIPERIODO%TYPE,
    P_CDEMPRESA      IN EMPRESA.CDEMPRESA%TYPE,
    P_CDINSCESTA     IN NOTAFISCAL.CDINSCESTA%TYPE,
    P_CDINSCESTAST   IN NOTAFISCAL.CDINSCESTAST%TYPE,
    P_NRSEQUMAPAPU   IN MAPAAPURACST.NRSEQUMAPAPU%TYPE)
AS
   V_DTINIFORPER      DATE;
   V_IDFORMAPUR       VARCHAR2(1);
   V_ICMSST           VARCHAR2(2);
   V_CDPAIS           VARCHAR2(4);
   V_SGESTADO         VARCHAR2(150);
   V_NRSEQUMAPAPU     VARCHAR2(10);
   V_VRCREDANTERIOR   NUMBER;
   V_VROUTROSDEB      NUMBER;
   V_VROUTROSCRED     NUMBER;
   V_VRIMPARECOLHER   NUMBER;
   V_VRSALDOCREDOR    NUMBER;
   V_VRTOTIMPREC      NUMBER;
   V_VRTOTSALDCRED    NUMBER;

BEGIN
   V_ICMSST          := '80';
   V_SGESTADO        := '_';
   V_VRCREDANTERIOR  := 0;
   V_VROUTROSDEB     := 0;
   V_VROUTROSCRED    := 0;
   V_VRIMPARECOLHER  := 0;
   V_VRSALDOCREDOR   := 0;
   V_VRTOTIMPREC     := 0;
   V_VRTOTSALDCRED   := 0;

   /*Busca a Data Inicial para as notas fora do perodo*/
   SELECT DTININFFORPER
     INTO V_DTINIFORPER
     FROM PARAMFISCAL;

   /*Update das notas de sada na IMPOSTONF para NULL em caso de reapurao de mapas*/
   UPDATE IMPOSTONF
      SET NRSEQUMAPAPUST = NULL
    WHERE NRSEQUMAPAPUST = P_NRSEQUMAPAPU;
   COMMIT;

   /*Verifica a forma de apurao do imposto - Data de Competncia, Data de Pagamento, Data de Emisso, Data de Entrada/Sada*/
   SELECT IDFORMAPURNFE
     INTO V_IDFORMAPUR
     FROM IMPOSTONFE I
    WHERE I.CDIMPOSTONFE = V_ICMSST;

   /*Apurao por Data de Competncia*/
   IF V_IDFORMAPUR = 'C' THEN
      UPDATE IMPOSTONF
         SET NRSEQUMAPAPUST = P_NRSEQUMAPAPU
       WHERE NRSEQUMAPAPUST IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE =  V_ICMSST)
         AND (NRLANCTONF, CDFILIAL) IN (SELECT NRLANCTONF, CDFILIAL
                                          FROM NOTAFISCAL N
                                         WHERE IDSTATUS     IN ('E','A')
                                           AND CDEMPRESA    = P_CDEMPRESA
                                           AND CDINSCESTA   = P_CDINSCESTA
                                           AND ((CDINSCESTAST = P_CDINSCESTAST) OR
                                                ((P_CDINSCESTAST IS NULL) AND (CDINSCESTAST IS NULL)))
                                           AND IDENTRSAIDOP = 'E'
                                           AND DTENTRSAID BETWEEN V_DTINIFORPER AND P_DTFINAL
                                           AND IDSISTEMA NOT IN ('PAG','REC','FIS','TMP')
                                         UNION ALL
                                        SELECT NRLANCTONF, CDFILIAL
                                          FROM NOTAFISCAL N
                                         WHERE IDSTATUS     IN ('E','A')
                                           AND CDEMPRESA    = P_CDEMPRESA
                                           AND CDINSCESTA   = P_CDINSCESTA
                                           AND ((CDINSCESTAST = P_CDINSCESTAST) OR
                                                ((P_CDINSCESTAST IS NULL) AND (CDINSCESTAST IS NULL)))
                                           AND IDENTRSAIDOP = 'S'
                                           AND DTEMISSAO BETWEEN V_DTINIFORPER AND P_DTFINAL
                                           AND IDSISTEMA NOT IN ('PAG','REC','FIS','TMP'));
   END IF;

   /*Apurao por Data de Entrada/Sada*/
   IF V_IDFORMAPUR = 'D' THEN
      UPDATE IMPOSTONF
         SET NRSEQUMAPAPUST = P_NRSEQUMAPAPU
       WHERE NRSEQUMAPAPUST IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE =  V_ICMSST)
         AND (NRLANCTONF, CDFILIAL) IN (SELECT NRLANCTONF, CDFILIAL
                                          FROM NOTAFISCAL N
                                         WHERE IDSTATUS     IN ('E','A')
                                           AND CDEMPRESA    = P_CDEMPRESA
                                           AND CDINSCESTA   = P_CDINSCESTA
                                           AND ((CDINSCESTAST = P_CDINSCESTAST) OR
                                                ((P_CDINSCESTAST IS NULL) AND (CDINSCESTAST IS NULL)))
                                           AND DTENTRSAID BETWEEN V_DTINIFORPER AND P_DTFINAL
                                           AND IDSISTEMA NOT IN ('PAG','REC','FIS','TMP'));
   END IF;

   /*Apurao por Data de Emisso*/
   IF V_IDFORMAPUR = 'E' THEN
      UPDATE IMPOSTONF
         SET NRSEQUMAPAPUST = P_NRSEQUMAPAPU
       WHERE NRSEQUMAPAPUST IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE =  V_ICMSST)
         AND (NRLANCTONF, CDFILIAL) IN (SELECT NRLANCTONF, CDFILIAL
                                          FROM NOTAFISCAL N
                                         WHERE IDSTATUS     IN ('E','A')
                                           AND CDEMPRESA    = P_CDEMPRESA
                                           AND CDINSCESTA   = P_CDINSCESTA
                                           AND ((CDINSCESTAST = P_CDINSCESTAST) OR
                                                ((P_CDINSCESTAST IS NULL) AND (CDINSCESTAST IS NULL)))
                                           AND DTEMISSAO BETWEEN V_DTINIFORPER AND P_DTFINAL
                                           AND IDSISTEMA NOT IN ('PAG','REC','FIS','TMP'));
   END IF;

   /*Apurao por Data de Pagamento*/
   IF V_IDFORMAPUR = 'P' THEN
      /*Notas de Entrada*/
      UPDATE IMPOSTONF
         SET NRSEQUMAPAPUST = P_NRSEQUMAPAPU
       WHERE NRSEQUMAPAPUST IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE =  V_ICMSST)
         AND (NRLANCTONF, CDFILIAL) IN (SELECT N.NRLANCTONF, N.CDFILIAL
                                          FROM NOTAFISCAL N, CONTAPAGAR C, BOLETPAGAR B, BAIXAPAGA BX
                                         WHERE N.CDEMPRESA    = P_CDEMPRESA
                                           AND CDINSCESTA     = P_CDINSCESTA
                                           AND ((CDINSCESTAST = P_CDINSCESTAST) OR
                                                ((P_CDINSCESTAST IS NULL) AND (CDINSCESTAST IS NULL)))
                                           AND IDSTATUS       IN ('A','E')
                                           AND N.IDENTRSAIDOP = 'E'
                                           AND N.CDFILIAL     = C.CDFILIAL
                                           AND N.NRLANCTONF   = C.NRLANCTONF
                                           AND C.CDFILIBPAG   = B.CDFILIAL
                                           AND C.NRLANBOLPAG  = B.NRLANBOLPAG
                                           AND B.CDFILIBAIPAG = BX.CDFILIAL
                                           AND B.NRBAIXAPAG   = BX.NRBAIXAPAG
                                           AND BX.CDEMPRESA   = P_CDEMPRESA
                                           AND BX.DTBAIXAPAG BETWEEN V_DTINIFORPER AND P_DTFINAL
                                           AND IDSISTEMA NOT IN ('PAG','REC','FIS','TMP'));

      /*Notas de Sada*/
      UPDATE IMPOSTONF
         SET NRSEQUMAPAPUST = P_NRSEQUMAPAPU
       WHERE NRSEQUMAPAPUST IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE = V_ICMSST)
         AND (CDFILIAL,NRLANCTONF) IN (SELECT N.CDFILIAL, N.NRLANCTONF
                                         FROM NOTAFISCAL N, CONTARECEBER C, BOLETRECEBER B, BAIXARECEBIDA BX
                                        WHERE N.CDEMPRESA    = P_CDEMPRESA
                                          AND CDINSCESTA     = P_CDINSCESTA
                                          AND ((CDINSCESTAST = P_CDINSCESTAST) OR
                                                ((P_CDINSCESTAST IS NULL) AND (CDINSCESTAST IS NULL)))
                                          AND IDSTATUS       IN ('A','E')
                                          AND N.IDENTRSAIDOP = 'S'
                                          AND N.CDFILIAL     = C.CDFILIAL
                                          AND N.NRLANCTONF   = C.NRLANCTONF
                                          AND C.CDFILIBOLREC = B.CDFILIAL
                                          AND C.NRLANBOLREC  = B.NRLANBOLREC
                                          AND B.CDFILIBAIREC = BX.CDFILIAL
                                          AND B.NRBAIXAREC   = BX.NRBAIXAREC
                                          AND BX.CDEMPRESA   = P_CDEMPRESA
                                          AND BX.DTBAIXAREC BETWEEN V_DTINIFORPER AND P_DTFINAL
                                          AND IDSISTEMA NOT IN ('PAG','REC','FIS','TMP'));
   END IF;

   /*Calcula os valores do Crdito Normal, Dbito Normal, Devoluo e Ressarcimento, agrupados por Estado e Pais*/
   FOR C_DETMAPA IN (SELECT REG.CDPAIS, REG.SGESTADO,
                            SUM(DECODE(E.IDREGIMEICMSST,'1',DECODE(REG.IDENTRSAIDOP,'E',ROUND(VRCREDITO,2),0),0)) AS VRCREDITO,
                            SUM(DECODE(REG.IDENTRSAIDOP,'S',ROUND(VRIMPOSTONF,2),0)) AS VRDEBITO,
                            SUM(DECODE(E.IDREGIMEICMSST,'1',DECODE(REG.IDENTRSAIDOP,'E',ROUND(VRDEVMAPA,2),0),0))   AS VRDEVMAPA,
                            SUM(DECODE(E.IDREGIMEICMSST,'1',DECODE(REG.IDENTRSAIDOP,'E',ROUND(VRRESSAMAPA,2),0),0)) AS VRRESSAMAPA
                       FROM IMPOSTONFE I, EMPRESA E,
                            (SELECT EC.CDPAIS, EC.SGESTADO, NF.IDENTRSAIDOP, NF.CDEMPRESA,
                                    CASE WHEN CDFISCOPERNF NOT IN ('1401','1406','1407','1410','1411','1414','1415','1603','1660','1661','1662','2401','2406','2407','2410','2411','2414','2415','2603','2660','2661','2662')
                                         THEN DECODE(IP.CDFISCALNF,'1',IP.VRIMPOSTONF,0) ELSE 0 END AS VRCREDITO,
                                    CASE WHEN CDFISCOPERNF NOT IN ('1401','1406','1407','1410','1411','1414','1415','1603','1660','1661','1662','2401','2406','2407','2410','2411','2414','2415','2603','2660','2661','2662')
                                         THEN DECODE(IP.CDFISCALNF,'1',IP.VRIMPOSTONF,0) ELSE 0 END AS VRIMPOSTONF,
                                    CASE WHEN CDFISCOPERNF IN ('1410','1411','1414','1415','1660','1661','1662','2410','2411','2414','2415','2660','2661','2662')
                                         THEN DECODE(IP.CDFISCALNF,'1',IP.VRIMPOSTONF,0) ELSE 0 END AS VRDEVMAPA,
                                    CASE WHEN CDFISCOPERNF IN ('1603', '2603')
                                         THEN DECODE(IP.CDFISCALNF,'1',IP.VRIMPOSTONF,0) ELSE 0 END AS VRRESSAMAPA
                               FROM IMPOSTONF IP, NOTAFISCAL NF, ENDECLIE EC
                              WHERE IP.NRSEQUMAPAPUST = P_NRSEQUMAPAPU
                                AND NF.CDFILIAL       = IP.CDFILIAL
                                AND NF.NRLANCTONF     = IP.NRLANCTONF
                                AND NF.IDORIGDESTNF   = 'C'
                                AND EC.CDCLIENTE      = NF.CDCLIENTE
                                AND EC.IDTPENDECLIE   = 'P'
                              UNION ALL
                             SELECT EF.CDPAIS, EF.SGESTADO, NF.IDENTRSAIDOP, NF.CDEMPRESA,
                                    CASE WHEN CDFISCOPERNF NOT IN ('1401','1406','1407','1410','1411','1414','1415','1603','1660','1661','1662','2401','2406','2407','2410','2411','2414','2415','2603','2660','2661','2662')
                                         THEN DECODE(IP.CDFISCALNF,'1',IP.VRIMPOSTONF,0) ELSE 0 END AS VRCREDITO,
                                    CASE WHEN CDFISCOPERNF NOT IN ('1401','1406','1407','1410','1411','1414','1415','1603','1660','1661','1662','2401','2406','2407','2410','2411','2414','2415','2603','2660','2661','2662')
                                         THEN DECODE(IP.CDFISCALNF,'1',IP.VRIMPOSTONF,0) ELSE 0 END AS VRIMPOSTONF,
                                    CASE WHEN CDFISCOPERNF IN ('1410','1411','1414','1415','1660','1661','1662','2410','2411','2414','2415','2660','2661','2662')
                                         THEN DECODE(IP.CDFISCALNF,'1',IP.VRIMPOSTONF,0) ELSE 0 END AS VRDEVMAPA,
                                    CASE WHEN CDFISCOPERNF IN ('1603', '2603')
                                         THEN DECODE(IP.CDFISCALNF,'1',IP.VRIMPOSTONF,0) ELSE 0 END AS VRRESSAMAPA
                             FROM IMPOSTONF IP, NOTAFISCAL NF, ENDEFORN EF
                            WHERE IP.NRSEQUMAPAPUST = P_NRSEQUMAPAPU
                              AND NF.CDFILIAL       = IP.CDFILIAL
                              AND NF.NRLANCTONF     = IP.NRLANCTONF
                              AND NF.IDORIGDESTNF   = 'F'
                              AND EF.CDFORNECED     = NF.CDFORNECED
                              AND EF.IDTPENDEFORN   = 'P'
                           UNION ALL
                           SELECT EL.CDPAIS, EL.SGESTADO, NF.IDENTRSAIDOP, NF.CDEMPRESA,
                                  CASE WHEN CDFISCOPERNF NOT IN  ('1401','1406','1407','1410','1411','1414','1415','1603','1660','1661','1662','2401','2406','2407','2410','2411','2414','2415','2603','2660','2661','2662')
                                       THEN DECODE(IP.CDFISCALNF,'1',IP.VRIMPOSTONF,0) ELSE 0 END AS VRCREDITO,
                                  CASE WHEN CDFISCOPERNF NOT IN ('1401','1406','1407','1410','1411','1414','1415','1603','1660','1661','1662','2401','2406','2407','2410','2411','2414','2415','2603','2660','2661','2662')
                                       THEN DECODE(IP.CDFISCALNF,'1',IP.VRIMPOSTONF,0) ELSE 0 END AS VRIMPOSTONF,
                                  CASE WHEN CDFISCOPERNF IN ('1410','1411','1414','1415','1660','1661','1662','2410','2411','2414','2415','2660','2661','2662')
                                       THEN DECODE(IP.CDFISCALNF,'1',IP.VRIMPOSTONF,0) ELSE 0 END AS VRDEVMAPA,
                                  CASE WHEN CDFISCOPERNF IN ('1603', '2603')
                                       THEN DECODE(IP.CDFISCALNF,'1',IP.VRIMPOSTONF,0) ELSE 0 END AS VRRESSAMAPA
                             FROM IMPOSTONF IP, NOTAFISCAL NF, ENDEFILI EL
                            WHERE IP.NRSEQUMAPAPUST = P_NRSEQUMAPAPU
                              AND NF.CDFILIAL       = IP.CDFILIAL
                              AND NF.NRLANCTONF     = IP.NRLANCTONF
                              AND NF.IDORIGDESTNF   = 'L'
                              AND EL.CDFILIAL       = DECODE(NF.IDENTRSAIDOP,'E',NF.CDFILIEMIT,NF.CDFILIRECE)
                              AND EL.IDTPENDEFILI   = 'P') REG
                      WHERE CDIMPOSTONFE = '80'
                        AND E.CDEMPRESA  = REG.CDEMPRESA
                      GROUP BY REG.CDPAIS, REG.SGESTADO) LOOP

      /*Busca o saldo do Perodo Anterior e os valores de Outros Crditos e Outros Dbitos*/
      V_VRCREDANTERIOR := -1;
      V_VROUTROSDEB    := 0;
      V_VROUTROSCRED   := 0;
      V_NRSEQUMAPAPU   := '';

      BEGIN
         SELECT NVL(VRCREDANTERIOR,-1),  NVL(VROUTROSDEB,0),  NVL(VROUTROSCRED,0), NRSEQUMAPAPU
           INTO V_VRCREDANTERIOR, V_VROUTROSDEB, V_VROUTROSCRED, V_NRSEQUMAPAPU
           FROM DETALHEAPURST
          WHERE CDPAIS       = C_DETMAPA.CDPAIS
            AND SGESTADO     = C_DETMAPA.SGESTADO
            AND NRSEQUMAPAPU = P_NRSEQUMAPAPU;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VRCREDANTERIOR := -1;
            V_VROUTROSDEB    := 0;
            V_VROUTROSCRED   := 0;
            V_NRSEQUMAPAPU   := '';
      END;

      IF V_VRCREDANTERIOR = -1 THEN
         BEGIN
            SELECT NVL(VRSALDOCREDOR,0)
              INTO V_VRCREDANTERIOR
              FROM DETALHEAPURST D
             WHERE NRSEQUMAPAPU = (SELECT NVL(MAX(DT.NRSEQUMAPAPU),0)
                                     FROM DETALHEAPURST DT, MAPAAPURACST MP
                                    WHERE DT.NRSEQUMAPAPU < P_NRSEQUMAPAPU
                                      AND DT.CDPAIS       = C_DETMAPA.CDPAIS
                                      AND DT.SGESTADO     = C_DETMAPA.SGESTADO
                                      AND DT.NRSEQUMAPAPU = MP.NRSEQUMAPAPU
                                      AND MP.CDEMPRESA    = P_CDEMPRESA
                                      AND MP.CDINSCESTA   = P_CDINSCESTA
                                      AND ((MP.CDINSCESTAST = P_CDINSCESTAST) OR
                                           ((P_CDINSCESTAST IS NULL) AND (MP.CDINSCESTAST IS NULL))))
               AND CDPAIS       = C_DETMAPA.CDPAIS
               AND SGESTADO     = C_DETMAPA.SGESTADO;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VRCREDANTERIOR := 0;
         END;
      END IF;

      /*Valor do Imposto  Pagar*/
      V_VRIMPARECOLHER := NVL(C_DETMAPA.VRDEBITO,0) - NVL(C_DETMAPA.VRDEVMAPA,0) - NVL(C_DETMAPA.VRRESSAMAPA,0) -
                          NVL(C_DETMAPA.VRCREDITO,0) - NVL(V_VRCREDANTERIOR,0) - NVL(V_VROUTROSCRED,0) + NVL(V_VROUTROSDEB,0);

      IF V_VRIMPARECOLHER < 0 THEN
         V_VRSALDOCREDOR  := ABS(NVL(V_VRIMPARECOLHER,0));
         V_VRIMPARECOLHER := 0;
      END IF;

      /*Verifica se j existia a linha referente ao Pas e Estado atual na MAPAAPURACST */
      IF V_NRSEQUMAPAPU IS NOT NULL THEN
         /*Updata os valores na tabela de Detalhamento*/
         UPDATE DETALHEAPURST
            SET VRDEBITONORMAL  = NVL(C_DETMAPA.VRDEBITO,0),
                VRCREDITONORMAL = NVL(C_DETMAPA.VRCREDITO,0),
                VRCREDANTERIOR  = NVL(V_VRCREDANTERIOR,0),
                VROUTROSDEB     = NVL(V_VROUTROSDEB,0),
                VROUTROSCRED    = NVL(V_VROUTROSCRED,0),
                VRDEVMAPA 	= NVL(C_DETMAPA.VRDEVMAPA,0),
                VRRESSAMAPA 	= NVL(C_DETMAPA.VRRESSAMAPA,0),
                VRIMPARECOLHER  = NVL(V_VRIMPARECOLHER,0),
                VRSALDOCREDOR   = NVL(V_VRSALDOCREDOR,0)
          WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU
            AND CDPAIS       = C_DETMAPA.CDPAIS
            AND SGESTADO     = C_DETMAPA.SGESTADO;
      ELSE
         /*Insere os valores na tabela de Detalhamento*/
         INSERT INTO DETALHEAPURST
           (NRSEQUMAPAPU, CDPAIS, SGESTADO, VRDEBITONORMAL, VRCREDITONORMAL, VRCREDANTERIOR,
            VROUTROSDEB, VROUTROSCRED, VRDEVMAPA, VRRESSAMAPA, VRIMPARECOLHER, VRSALDOCREDOR)
         VALUES
           (P_NRSEQUMAPAPU, C_DETMAPA.CDPAIS, C_DETMAPA.SGESTADO, NVL(C_DETMAPA.VRDEBITO,0), NVL(C_DETMAPA.VRCREDITO,0),
            NVL(V_VRCREDANTERIOR,0), NVL(V_VROUTROSDEB,0), NVL(V_VROUTROSCRED,0), NVL(C_DETMAPA.VRDEVMAPA,0),
            NVL(C_DETMAPA.VRRESSAMAPA,0), NVL(V_VRIMPARECOLHER,0), NVL(V_VRSALDOCREDOR,0));
      END IF;
      V_CDPAIS        := C_DETMAPA.CDPAIS;
      V_SGESTADO      := V_SGESTADO || C_DETMAPA.SGESTADO || '_';

      V_VRTOTIMPREC   := V_VRTOTIMPREC   + NVL(V_VRIMPARECOLHER,0);
      V_VRTOTSALDCRED := V_VRTOTSALDCRED + NVL(V_VRSALDOCREDOR,0);

   END LOOP;

   /*Deleta os estados que deixaram de existir na tabela de detalhamento*/
   DELETE FROM DETALHEAPURST
    WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU
      AND CDPAIS       = V_CDPAIS
      AND INSTR(V_SGESTADO, '_' || SGESTADO || '_') < 0;

   /*Atualiza o valor total dos Impostos*/
   V_VRTOTIMPREC := V_VRTOTIMPREC - V_VRTOTSALDCRED;

   IF V_VRTOTIMPREC < 0 THEN
      V_VRTOTSALDCRED := ABS(NVL(V_VRTOTIMPREC,0));
      V_VRTOTIMPREC   := 0;
   END IF;

   /*Updata os valores na tabela do Mapa de Apurao*/
   UPDATE MAPAAPURACST
      SET VRTOTAIMPOS  = V_VRTOTIMPREC
    WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU;
   COMMIT;
END;
/
-- VERSAO --
BEGIN ATUVEROBJ('APURA_ICMSST_IESUBSTITUTO','5.67.000'); END;
/